@@ -10,7 +10,14 @@ describe 'openstacklib mysql' do
 
       class { 'mysql::server': }
 
-      ::openstacklib::db::mysql { 'ci':
+      $charset = $::operatingsystem ? {
+        'Ubuntu' => 'utf8mb3',
+        default  => 'utf8',
+      }
+
+      openstacklib::db::mysql { 'ci':
+        charset       => $charset,
+        collate       => "${charset}_general_ci",
         password_hash => mysql::password('keystone'),
         allowed_hosts => '127.0.0.1',
       }
